@@ -22,6 +22,9 @@ class GridHandler():
             default=1)
         parser.add_argument('-s','--site', help='site to submit the job to '
             '(this will override the grid config site setting)', choices=kGPUGridSiteList)
+        parser.add_argument('-t','--time', help='same as maxCpuCount in prun which '
+            'specifies the maximum cpu time for a job (prevent being killed by'
+            'looping job detection)', type=int, default=-1)
         return parser
 
     def run_parser(self):
@@ -30,10 +33,10 @@ class GridHandler():
             args = parser.parse_args(sys.argv[2:])
         else:
             args = parser.parse_args(sys.argv[1:])
-        GridHandler.submit_job(args.proj_name, args.n_jobs, args.site)
+        GridHandler.submit_job(args.proj_name, args.n_jobs, args.site, args.time)
                 
     @staticmethod
-    def submit_job(proj_name, n_jobs=1, site=None):
+    def submit_job(proj_name, n_jobs=1, site=None, time=-1):
 
         grid_config = helper.get_project_config(proj_name)['grid_config']
 
@@ -63,6 +66,8 @@ class GridHandler():
         if '{HPO_PROJECT_NAME}' in grid_config['outDS']:
             grid_config['outDS'] = grid_config['outDS'].format(HPO_PROJECT_NAME=proj_name)
         options['outDS'] = grid_config['outDS']
+        if time != -1:
+            options['maxCpuCount'] = str(time)
 
         if not site:
             site = grid_config['site']
@@ -78,7 +83,8 @@ class GridHandler():
 
         # construct prun command
         command = stylus.join_options(options)
-
+        #from pdb import set_trace
+        #set_trace()
         # switch to working directory to send files to WNs
         with helper.cd(project_path):
             # submit grid jobs
