@@ -289,7 +289,7 @@ class JobBuilder():
             json.dump({}, output)
         #ray.init(node_ip_address="127.0.0.1", ignore_reinit_error=True)
         try:
-            ray.init(ignore_reinit_error=True)
+            #ray.init()
 
             analysis = tune.run(
                 model,
