@@ -21,20 +21,37 @@ class NpEncoder(json.JSONEncoder):
             return obj.tolist()
         else:
             return super(NpEncoder, self).default(obj)
+
+def local_setup():
+    os.environ['HPOGRID_DATA_DIR'] = os.getcwd()
+    os.environ['HPOGRID_WORK_DIR'] = os.getcwd()
         
 def grid_site_setup():
     os.environ['ENABLE_HPOGRID_RUN'] = 'TRUE'
-    os.environ['HPOGRID_DATA_DIR'] = kDataDir
-    os.environ['HPOGRID_WORK_DIR'] = kWorkDir
+    # there is probably a better way to get the working directory but 
+    # for now just follow https://twiki.cern.ch/twiki/bin/viewauth/AtlasComputing/SingularityInAtlas
+    # to use os.getcwd()
+    os.environ['HPOGRID_DATA_DIR'] = os.getcwd()
+    os.environ['HPOGRID_WORK_DIR'] = os.getcwd()
+
+def get_workdir():
+    return os.environ.get('HPOGRID_WORK_DIR', os.getcwd())
+
+def get_datadir():
+    return os.environ.get('HPOGRID_DATA_DIR', os.getcwd())
 
 def is_grid_job_running():
     return os.environ.get('ENABLE_HPOGRID_RUN', None)=='TRUE'
 
+def set_base_path(path:str) -> None:
+    os.environ[kHPOGridEnvPath] = path
+
 def get_base_path():
     if kHPOGridEnvPath not in os.environ:
-        raise KeyError('{} environment variable not set.'
-            'Try source setupenv.sh first.'.format(kHPOGridEnvPath))
-    return os.environ[kHPOGridEnvPath]
+        print('WARNING: {} environment variable not set.'
+            'Set to current working directory by default.'.format(kHPOGridEnvPath))
+        self.set_base_path(os.getcwd())
+    return os.environ.get(kHPOGridEnvPath, os.getcwd())
 
 def set_script_path(proj_name, undo=False):
     project_path = get_project_path(proj_name)
@@ -50,7 +67,7 @@ def set_script_path(proj_name, undo=False):
 
 def get_project_path(proj_name):
     if is_grid_job_running():
-        proj_path = kDataDir
+        proj_path = get_datadir()
     else:
         base_path = get_base_path()
         proj_path = os.path.join(base_path, 'project', proj_name)
@@ -82,8 +99,8 @@ def get_physical_devices(device_type='GPU'):
     return physical_devices
 
 def get_n_gpu():
-    physical_devices = get_physical_devices('GPU')
-    return len(physical_devices)
+	import torch
+	return torch.cuda.device_count()	
 
 def get_n_cpu():
     return multiprocessing.cpu_count()
